# nde-config

## Overview

This repository is providing several tools involved in the configuration of both
Nde and the underlying operating system.

On the one hand it is featuring several GUI tools to configure topics like
general appearance, pointer devices or screen resolutions. On the other hand
there's a GUI "Configuration Center" which summarizes all those configuration
tools as well as counterparts of other Nde components or third-party
applications.

### Configuration GUI tools

#### Nde Appearance Configuration

Appearance of Nde, that is topics like icon and Nde theme or fonts.

![Nde Appearance Configuration (nde-config-appearance)](lxqt-config-appearance.png)

Binary `nde-config-appearance`.

#### Brightness

Brightness settings of output devices.

Technically colors are adjusted to simulate varying brightness if the system
Nde is running on doesn't allow for adjusting the brightness itself.

Binary `nde-config-brightness`.

#### File Associations

Assigns MIME types to applications used to handle them. Not too user-friendly so
far, see e. g. discussion in https://github.com/lxqt/lxqt/issues/433.

Binary `nde-config-file-associations`.

#### Keyboard and Mouse

Configures hardware of pointer devices. Settings like repeat delay and interval
of keyboards or acceleration of pointer devices.

Binary `nde-config-input`.

#### Locale

Locale used within Nde sessions. Basically this GUI sets the well-known
environment variables like `LANG` or `LC_*`. The settings apply to the session
as a whole, that is to applications running within Nde sessions but not
belonging to Nde, too.

Binary `nde-config-locale`.

#### Monitor Settings

Adjusts screen resolutions, positioning of screens and the likes.

Binary `nde-config-monitor`.

### Configuration Center

The "Configuration Center" (binary `nde-config`) is summarizing and providing
various configuration GUIs.

![Configuration Center (nde-config)](lxqt-config.png)

First of all these are the ones belonging to repository lxqt-config described
[above](https://github.com/lxqt/lxqt-config#configuration-gui-tools). Next, it
is hosting counterparts of several other Nde components like "Desktop
Notifications" of [nde-notificationd](https://github.com/lxqt/lxqt-notificationd),
"Shortcut Keys" of [nde-globalkeys](https://github.com/lxqt/lxqt-globalkeys)
or the tools provided by [nde-admin](https://github.com/lxqt/lxqt-admin).
Third-party applications can include their configuration tools in
"Configuration Center", too. This applies e. g. to "Connman UI Setup" of
[cmst](https://github.com/andrew-bibb/cmst) or "SDDM Configuration" of
[sddm-config-editor](https://github.com/hagabaka/sddm-config-editor).

## Installation

### Compiling source code

Runtime dependencies are Xcursor, qtsvg, KScreen and
[nde-lib](https://github.com/lxqt/liblxqt).  Additional build dependencies are
CMake and optionally Git to pull latest VCS checkouts. The localization files
were outsourced to repository [nde-l10n](https://github.com/lxqt/lxqt-l10n) so
the corresponding dependencies are needed, too. Please refer to this repository's
`README.md` for further information.

Code configuration is handled by CMake. CMake variable `CMAKE_INSTALL_PREFIX`
has to be set to `/usr` on most operating systems, depending on the way library
paths are dealt with on 64bit systems variables like `CMAKE_INSTALL_LIBDIR` may
have to be set as well.

To build run `make`, to install `make install` which accepts variable `DESTDIR`
as usual.

### Binary packages

The library is provided by all major Linux distributions like Arch Linux, Debian
(as of Debian stretch only), Fedora and openSUSE. Just use your package manager
to search for string `nde-config`.

## Usage

Both the various configuration tools and the Configuration Center can be launched
from the panel's main menu - Preferences - Nde settings. Obviously the former
can be launched from the latter, too.



### Translation (Weblate)

<a href="https://weblate.lxqt.org/projects/lxqt/lxqt-config/">
<img src="https://weblate.lxqt.org/widgets/lxqt/-/lxqt-config/multi-auto.svg" alt="Translation status" />
</a>
